@@ -31,6 +31,9 @@ def _create_reader(numbering, content_types, relationships, styles, docx_file):
         "w:del",
         "w:pPr",
         "w:rPr",
+        "w:tblPr",
+        "w:tblGrid",
+        "w:tcPr",
     ])
 
     def handler(name):
@@ -119,6 +122,24 @@ def _create_reader(numbering, content_types, relationships, styles, docx_file):
         return results.success(documents.tab())
     
     
+    @handler("w:tbl")
+    def table(element):
+        return _read_xml_elements(element.children) \
+            .map(documents.table)
+    
+    
+    @handler("w:tr")
+    def table(element):
+        return _read_xml_elements(element.children) \
+            .map(documents.table_row)
+    
+    
+    @handler("w:tc")
+    def table(element):
+        return _read_xml_elements(element.children) \
+            .map(documents.table_cell)
+    
+    
     @handler("w:ins")
     @handler("w:smartTag")
     @handler("w:drawing")
